@@ -24,8 +24,75 @@
 # ###########################################################################*/
 
 """
-This module provides global definitions and methods to transform
-a tomo dataset written in edf into and hdf5/nexus file
+Application to convert a tomo dataset written in bliss- hdf5 - 3D-XRD into and hdf5/nexus file
+
+.. code-block:: bash
+
+    usage: nxtomomill h5-3dxrd-2nx [-h] [--file-extension FILE_EXTENSION] [--single-file] [--overwrite] [--debug] [--entries ENTRIES] [--ignore-sub-entries IGNORE_SUB_ENTRIES] [--raises-error]
+                                   [--field-of-view FIELD_OF_VIEW] [--no-input] [--x_trans_keys X_TRANS_KEYS] [--y_trans_keys Y_TRANS_KEYS] [--z_trans_keys Z_TRANS_KEYS]
+                                   [--sample-detector-distance SAMPLE_DETECTOR_DISTANCE] [--valid_camera_names VALID_CAMERA_NAMES] [--rot_angle_keys ROT_ANGLE_KEYS] [--acq_expo_time_keys ACQ_EXPO_TIME_KEYS]
+                                   [--x_pixel_size_key X_PIXEL_SIZE_KEY] [--y_pixel_size_key Y_PIXEL_SIZE_KEY] [--init_titles INIT_TITLES] [--init_zserie_titles INIT_ZSERIE_TITLES] [--dark_titles DARK_TITLES]
+                                   [--ref_titles REF_TITLES] [--proj_titles PROJ_TITLES] [--align_titles ALIGN_TITLES] [--set-params [SET_PARAMS [SET_PARAMS ...]]] [--config CONFIG]
+                                   [input_file] [output_file]
+
+    convert data acquired as hdf5 from bliss to nexus `NXtomo` classes. For `zseries` it will create one entry per `z`
+
+    positional arguments:
+      input_file            master file of the acquisition
+      output_file           output .nx or .h5 file
+
+    optional arguments:
+      -h, --help            show this help message and exit
+      --file-extension FILE_EXTENSION, --file_extension FILE_EXTENSION
+                            extension of the output file. Valid values are .h5/.hdf5/.nx
+      --single-file         merge all scan sequence to the same output file. By default create one file per sequence and group all sequence in the output file
+      --overwrite           Do not ask for user permission to overwrite output files
+      --debug               Set logs to debug mode
+      --entries ENTRIES     Specify (root) entries to be converted. By default it will try to convert all existing entries.
+      --ignore-sub-entries IGNORE_SUB_ENTRIES
+                            Specify (none-root) sub entries to ignore.
+      --raises-error        Raise errors if some data are not met instead of providing some default values
+      --field-of-view FIELD_OF_VIEW
+                            Force the output to be `Half` or `Full` acquisition. Otherwise parse raw data to find this information.
+      --no-input, --no-input-for-missing-information
+                            The user won't be ask for any inputs
+      --x_trans_keys X_TRANS_KEYS, --x-trans-keys X_TRANS_KEYS
+                            x translation key in bliss HDF5 file
+      --y_trans_keys Y_TRANS_KEYS, --y-trans-keys Y_TRANS_KEYS
+                            y translation key in bliss HDF5 file
+      --z_trans_keys Z_TRANS_KEYS, --z-trans-keys Z_TRANS_KEYS
+                            z translation key in bliss HDF5 file
+      --sample-detector-distance SAMPLE_DETECTOR_DISTANCE, --distance SAMPLE_DETECTOR_DISTANCE
+                            sample detector distance
+      --valid_camera_names VALID_CAMERA_NAMES, --valid-camera-names VALID_CAMERA_NAMES
+                            Valid NXDetector dataset name to be considered. Otherwise willtry to deduce them from NX_class attibute (value should beNXdetector) or from instrument group child structure.
+      --rot_angle_keys ROT_ANGLE_KEYS, --rot-angle-keys ROT_ANGLE_KEYS
+                            Valid dataset name for rotation angle
+      --acq_expo_time_keys ACQ_EXPO_TIME_KEYS, --acq-expo-time-keys ACQ_EXPO_TIME_KEYS
+                            Valid dataset name for acquisition exposure time
+      --x_pixel_size_key X_PIXEL_SIZE_KEY, --x-pixel-size-key X_PIXEL_SIZE_KEY
+                            X pixel size key to read
+      --y_pixel_size_key Y_PIXEL_SIZE_KEY, --y-pixel-size-key Y_PIXEL_SIZE_KEY
+                            Y pixel size key to read
+      --init_titles INIT_TITLES, --init-titles INIT_TITLES
+                            Titles corresponding to init scans
+      --init_zserie_titles INIT_ZSERIE_TITLES, --init-zserie-titles INIT_ZSERIE_TITLES
+                            Titles corresponding to zserie init scans
+      --dark_titles DARK_TITLES, --dark-titles DARK_TITLES
+                            Titles corresponding to dark scans
+      --flat-titles --flat_titles --ref_titles REF_TITLES, --ref-titles FLAT_TITLES
+                            Titles corresponding to ref scans
+      --proj_titles PROJ_TITLES, --proj-titles PROJ_TITLES
+                            Titles corresponding to projection scans
+      --align_titles ALIGN_TITLES, --align-titles ALIGN_TITLES
+                            Titles corresponding to alignment scans
+      --set-params [SET_PARAMS [SET_PARAMS ...]]
+                            Allow manual definition of some parameters. Valid parameters (and expected input unit) are: energy (kev), x_pixel_size (m), y_pixel_size (m). Should be added at the end of the command
+                            line because will try to cover all text set after this option.
+      --config CONFIG, --config-file CONFIG, --configuration CONFIG, --configuration-file CONFIG
+                            file containing the full configuration to convert from h5 bliss to nexus
+
+
 """
 
 __authors__ = ["C. Nemoz", "H. Payno", "A.Sole"]
@@ -226,10 +293,13 @@ def main(argv):
         help="Titles corresponding to dark scans",
     )
     parser.add_argument(
+        "--flat_titles",
+        "--flat-titles",
         "--ref_titles",
         "--ref-titles",
         default=None,
         help="Titles corresponding to ref scans",
+        dest="flat_titles",
     )
     parser.add_argument(
         "--proj_titles",
