@@ -35,6 +35,8 @@ __date__ = "27/11/2020"
 
 
 from collections import namedtuple
+from typing import Optional
+from nxtomomill.converter.hdf5.acquisition.baseacquisition import SourceType
 from nxtomomill import utils
 from nxtomomill.utils import ImageKey
 from nxtomomill.converter.version import version as converter_version
@@ -44,6 +46,7 @@ from nxtomomill.settings import Tomo
 from tomoscan.esrf.edfscan import EDFTomoScan
 from tomoscan.unitsystem import metricsystem
 from tomoscan.io import HDF5File
+import datetime
 import fabio
 import numpy
 import os
@@ -97,6 +100,11 @@ def edf_to_nx(
     file_extension: str,
     file_keys: EDFFileKeys = DEFAULT_EDF_KEYS,
     progress=None,
+    sample_name: Optional[str] = None,
+    title: Optional[str] = None,
+    instrument_name: Optional[str] = None,
+    source_name: Optional[str] = None,
+    source_type: Optional[SourceType] = None,
 ) -> tuple:
     """
     Convert an edf file to a nexus file.
@@ -107,6 +115,11 @@ def edf_to_nx(
     :param file_extension:
     :param file_keys:
     :param progress:
+    :param Optional[str] sample_name: name of the sample
+    :param Optional[str] title: dataset title
+    :param Optional[str] instrument_name: name of the instrument used
+    :param Optional[str] source_name: name of the source (most likely ESRF)
+    :param Optional[str] source_type: type of the source (most likely "Synchrotron X-ray Source")
     :return: (nexus_file, entry)
     :rtype:tuple
     """
@@ -120,6 +133,9 @@ def edf_to_nx(
     )
     _logger.info("Output file will be " + fileout_h5)
 
+    if source_type is not None:
+        source_type = SourceType.from_value(source_type)
+
     DARK_ACCUM_FACT = True
     with HDF5File(fileout_h5, "w") as h5d:
         proj_urls = scan.get_proj_urls(scan=scan.path)
@@ -136,7 +152,11 @@ def edf_to_nx(
                 _edf_to_ignore.append("HST")
             else:
                 _edf_to_ignore.remove("HST")
-            refs_urls = scan.get_refs_url(
+            try:
+                get_flats_url = scan.get_flats_url
+            except ImportError:
+                get_flats_url = scan.get_refs_url
+            refs_urls = get_flats_url(
                 scan_path=scan.path, prefix=refs_to_find, ignore=_edf_to_ignore
             )
             if len(refs_urls) > 0:
@@ -150,41 +170,51 @@ def edf_to_nx(
             indexes = sorted(projections_urls.keys())
             first_proj_file = projections_urls[indexes[0]]
             fid = fabio.open(first_proj_file.file_path())
-            if hasattr(fid, "header"):
-                hd = fid.header
-            else:
-                hd = fid.getHeader()
             try:
-                rotangle_index = (
-                    hd[file_keys.motor_mne_key]
-                    .split(" ")
-                    .index(file_keys.rot_angle_key)
-                )
-            except:
-                rotangle_index = -1
-            try:
-                xtrans_index = (
-                    hd[file_keys.motor_mne_key].split(" ").index(file_keys.x_trans_key)
-                )
-            except:
-                xtrans_index = -1
-            try:
-                ytrans_index = (
-                    hd[file_keys.motor_mne_key].split(" ").index(file_keys.y_trans_key)
-                )
-            except:
-                ytrans_index = -1
-            try:
-                ztrans_index = (
-                    hd[file_keys.motor_mne_key].split(" ").index(file_keys.z_trans_key)
-                )
-            except:
-                ztrans_index = -1
+                if hasattr(fid, "header"):
+                    hd = fid.header
+                else:
+                    hd = fid.getHeader()
+                try:
+                    rotangle_index = (
+                        hd[file_keys.motor_mne_key]
+                        .split(" ")
+                        .index(file_keys.rot_angle_key)
+                    )
+                except:
+                    rotangle_index = -1
+                try:
+                    xtrans_index = (
+                        hd[file_keys.motor_mne_key]
+                        .split(" ")
+                        .index(file_keys.x_trans_key)
+                    )
+                except:
+                    xtrans_index = -1
+                try:
+                    ytrans_index = (
+                        hd[file_keys.motor_mne_key]
+                        .split(" ")
+                        .index(file_keys.y_trans_key)
+                    )
+                except:
+                    ytrans_index = -1
+                try:
+                    ztrans_index = (
+                        hd[file_keys.motor_mne_key]
+                        .split(" ")
+                        .index(file_keys.z_trans_key)
+                    )
+                except:
+                    ztrans_index = -1
 
-            if hasattr(fid, "bytecode"):
-                frame_type = fid.bytecode
-            else:
-                frame_type = fid.getByteCode()
+                if hasattr(fid, "bytecode"):
+                    frame_type = fid.bytecode
+                else:
+                    frame_type = fid.getByteCode()
+            finally:
+                fid.close()
+                fid = None
             return frame_type, rotangle_index, xtrans_index, ytrans_index, ztrans_index
 
         (
@@ -211,7 +241,26 @@ def edf_to_nx(
             dtype=numpy.int32,
         )
 
-        h5d["/entry/sample/name"] = os.path.basename(scan.path)
+        h5d["/entry/title"] = (
+            title if title is not None else os.path.basename(scan.path)
+        )
+
+        if sample_name is None:
+            try:
+                sample_name = os.path.abspath(scan.path).split(os.sep)[-3:]
+            except:
+                sample_name = "unknow"
+        h5d["/entry/sample/name"] = sample_name
+        if instrument_name is not None:
+            instrument_grp = h5d["/entry"].require_group("instrument")
+            instrument_grp["name"] = instrument_name
+
+        if source_name is not None:
+            source_grp = h5d["/entry/instrument"].require_group("source")
+            source_grp["name"] = source_name
+        if source_type is not None:
+            source_grp = h5d["/entry/instrument"].require_group("source")
+            source_grp["type"] = source_type.value
 
         proj_angle = scan.scan_range / scan.tomo_n
 
@@ -302,24 +351,29 @@ def edf_to_nx(
                     " for more information)" % url.path()
                 )
 
-            if fabio_file.nframes == 1:
-                if index != 0:
-                    raise ValueError(
-                        "Only a single frame available. Slice %s out of range" % index
-                    )
-                data = fabio_file.data
-                header = fabio_file.header
-            else:
-                data = fabio_file.getframe(index).data
-                header = fabio_file.getframe(index).header
-
-            fabio_file.close()
-            fabio_file = None
+            try:
+                if fabio_file.nframes == 1:
+                    if index != 0:
+                        raise ValueError(
+                            "Only a single frame available. Slice %s out of range"
+                            % index
+                        )
+                    data = fabio_file.data
+                    header = fabio_file.header
+                else:
+                    data = fabio_file.getframe(index).data
+                    header = fabio_file.getframe(index).header
+            except Exception as e:
+                data = None
+                header = None
+            finally:
+                fabio_file.close()
+                fabio_file = None
             return data, header
 
         if progress is not None:
             progress.set_name("write dark")
-            progress.set_max_advancement(len(dk_urls))
+            progress.reset(len(dk_urls))
 
         def ignore(file_name):
             for forbid in _edf_to_ignore:
@@ -335,7 +389,7 @@ def edf_to_nx(
             norm_dark = len(dk_urls) / scan.dark_n
         dk_indexes = sorted(dk_urls.keys())
         if progress is not None:
-            progress.set_max_advancement(len(dk_urls))
+            progress.reset(len(dk_urls))
         for dk_index in dk_indexes:
             dk_url = dk_urls[dk_index]
             if ignore(os.path.basename(dk_url.file_path())):
@@ -406,9 +460,6 @@ def edf_to_nx(
             ztix,
         ):
             nfr = nF
-            if progress is not None:
-                progress.set_name("write refs")
-                progress.set_max_advancement(len(refIndexes))
             for ref_index in refIndexes:
                 int_rf = int(ref_index)
                 test_val = 0
@@ -441,17 +492,13 @@ def edf_to_nx(
                             zDataset[nfr] = float(str_mot_val[ztix])
 
                     nfr += 1
-                    if progress is not None:
-                        progress.increase_advancement(i=1)
             return nfr
 
         # projections
-        import datetime
-
         proj_indexes = sorted(proj_urls.keys())
         if progress is not None:
-            progress.set_name("write projections")
-            progress.set_max_advancement(len(proj_indexes))
+            progress.set_name("write projections and flats")
+            progress.reset(len(proj_indexes))
         nproj = 0
         iref_pj = 0
 
@@ -551,6 +598,9 @@ def edf_to_nx(
         h5d["/entry/instrument/detector/data"].attrs["interpretation"] = u"image"
         h5d["/entry/sample"].attrs["NX_class"] = u"NXsample"
         h5d["/entry/definition"] = "NXtomo"
+        source_grp = h5d["/entry/instrument"].get("source", None)
+        if source_grp is not None and "NX_class" not in source_grp.attrs:
+            source_grp.attrs["NX_class"] = "NXsource"
 
         h5d.flush()
 
