@@ -402,7 +402,7 @@ class StandardAcquisition(BaseAcquisition):
                     root_node=entry,
                     resource_name=resource_name,
                     n_frame=None,
-                )
+                )[0]
             )
         for resource_name in self._plugins_instr_resources:
             assert isinstance(resource_name, str), "resource_name should be a string"
@@ -411,12 +411,14 @@ class StandardAcquisition(BaseAcquisition):
                     root_node=entry,
                     resource_name=resource_name,
                     n_frame=None,
-                )
+                )[0]
             )
         self._current_scan_n_frame = n_frame
 
     def camera_is_valid(self, det_name):
         assert isinstance(det_name, str)
+        if self.configuration.valid_camera_names is None:
+            return True
         for vcm in self.configuration.valid_camera_names:
             if fnmatch.fnmatch(det_name, vcm):
                 return True
@@ -538,11 +540,35 @@ class StandardAcquisition(BaseAcquisition):
         )
         return values, unit
 
+    def get_already_defined_params(self, key):
+        defined = self.__get_extra_param(key=key)
+        if len(defined) > 1:
+            raise ValueError("{} are aliases. Only one should be defined")
+        elif len(defined) == 0:
+            return None
+        else:
+            return list(defined.values())[0]
+
+    def __get_extra_param(self, key) -> dict:
+        """return already defined parameters for one key.
+        A key as aliases so it returns a dict"""
+        aliases = list(TomoHDF5Config.EXTRA_PARAMS_ALIASES[key])
+        aliases.append(key)
+        res = {}
+        for alias in aliases:
+            if alias in self.configuration.param_already_defined:
+                res[alias] = self.configuration.param_already_defined[alias]
+        return res
+
     def _write_beam(self, root_node, request_input, input_callback):
         instrument_node = root_node.require_group("instrument")
         beam_node = instrument_node.require_group("beam")
-        if "energy" in self.configuration.param_already_defined:
-            energy = float(self.configuration.param_already_defined["energy"])
+
+        already_defined = self.get_already_defined_params(
+            key=TomoHDF5Config.EXTRA_PARAMS_ENERGY_DK
+        )
+        if already_defined is not None:
+            energy = float(already_defined)
             unit = "kev"
         else:
             energy, unit = self._get_energy(
@@ -576,15 +602,11 @@ class StandardAcquisition(BaseAcquisition):
             detector_node["count_time"] = self._acq_expo_time
             detector_node["count_time"].attrs["unit"] = "s"
         # write distance
-        if (
-            TomoHDF5Config.EXTRA_PARAMS_DISTANCE
-            in self.configuration.param_already_defined
-        ):
-            distance = float(
-                self.configuration.param_already_defined[
-                    TomoHDF5Config.EXTRA_PARAMS_DISTANCE
-                ]
-            )
+        already_defined = self.get_already_defined_params(
+            key=TomoHDF5Config.EXTRA_PARAMS_DISTANCE
+        )
+        if already_defined is not None:
+            distance = float(already_defined)
             unit = "m"
         else:
             distance, unit = self._get_distance()
@@ -594,10 +616,11 @@ class StandardAcquisition(BaseAcquisition):
         # write x and y pixel size
         # if magnified pixel size is found then we right this value.
         # otherwise will take pixel size (if found)
-        if "x_pixel_size" in self.configuration.param_already_defined:
-            x_pixel_size = float(
-                self.configuration.param_already_defined["x_pixel_size"]
-            )
+        already_defined = self.get_already_defined_params(
+            key=TomoHDF5Config.EXTRA_PARAMS_X_PIXEL_SIZE_DK
+        )
+        if already_defined is not None:
+            x_pixel_size = float(already_defined)
             unit = "m"
         else:
             x_pixel_size, unit = self._get_pixel_size("x")
@@ -605,10 +628,11 @@ class StandardAcquisition(BaseAcquisition):
             detector_node["x_pixel_size"] = x_pixel_size
             detector_node["x_pixel_size"].attrs["unit"] = unit
 
-        if "y_pixel_size" in self.configuration.param_already_defined:
-            y_pixel_size = float(
-                self.configuration.param_already_defined["y_pixel_size"]
-            )
+        already_defined = self.get_already_defined_params(
+            key=TomoHDF5Config.EXTRA_PARAMS_Y_PIXEL_SIZE_DK
+        )
+        if already_defined is not None:
+            y_pixel_size = float(already_defined)
             unit = "m"
         else:
             y_pixel_size, unit = self._get_pixel_size("y")
@@ -1039,7 +1063,7 @@ class StandardAcquisition(BaseAcquisition):
 
         # check scan is complete
         tomo_n = self._get_tomo_n()
-        if tomo_n is not None:
+        if self.configuration.check_tomo_n and tomo_n is not None:
             image_key_control = numpy.asarray(self._image_key_control)
             proj_found = len(
                 image_key_control[image_key_control == ImageKey.PROJECTION.value]
