@@ -55,18 +55,7 @@ import uuid
 from silx.io.utils import h5py_read_dataset
 import h5py._hl.selections as selection
 from h5py import h5s as h5py_h5s
-
-
-class ImageKey(_Enum):
-    """
-    Possible values of image_key_control
-    """
-
-    ALIGNMENT = -1
-    PROJECTION = 0
-    FLAT_FIELD = 1
-    DARK_FIELD = 2
-    INVALID = 3
+from tomoscan.esrf.hdf5scan import ImageKey
 
 
 class FieldOfView(_Enum):
