@@ -76,11 +76,10 @@ RELEASE_LEVEL_VALUE = {
 }
 
 MAJOR = 0
-MINOR = 6
-MICRO = 3
-RELEV = "final"  # <16
+MINOR = 7
+MICRO = 1
+RELEV = "final"
 SERIAL = 0  # <16
-
 date = __date__
 
 from collections import namedtuple
